# Usage

The following pages provide some examples of how to use AmpForm. You can run
each of them as Jupyter notebooks with the {fa}`rocket` launch button in the
top-right corner.

```{toctree}
---
maxdepth: 2
---
usage/amplitude
usage/modify
usage/interactive
usage/formalism
usage/dynamics
```
